==> zio-aws-ec2_2.12-5.17.161.1-sources.jar: zio/aws/ec2/model/PrefixListId.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class PrefixListId(
    description: Option[String] = None,
    prefixListId: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.PrefixListId = {
    import PrefixListId.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.PrefixListId
      .builder()
      .optionallyWith(description.map(value => value: java.lang.String))(
        _.description
      )
      .optionallyWith(prefixListId.map(value => value: java.lang.String))(
        _.prefixListId
      )
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.PrefixListId.ReadOnly =
    zio.aws.ec2.model.PrefixListId.wrap(buildAwsValue())
}
object PrefixListId {
  private lazy val zioAwsBuilderHelper
      : BuilderHelper[software.amazon.awssdk.services.ec2.model.PrefixListId] =
    BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.PrefixListId =
      zio.aws.ec2.model.PrefixListId(
        description.map(value => value),
        prefixListId.map(value => value)
      )
    def description: Option[String]
    def prefixListId: Option[String]
    def getDescription: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("description", description)
    def getPrefixListId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("prefixListId", prefixListId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.PrefixListId
  ) extends zio.aws.ec2.model.PrefixListId.ReadOnly {
    override val description: Option[String] =
      scala.Option(impl.description()).map(value => value: String)
    override val prefixListId: Option[String] =
      scala.Option(impl.prefixListId()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.PrefixListId
  ): zio.aws.ec2.model.PrefixListId.ReadOnly = new Wrapper(impl)
}

==> zio-aws-ec2_2.12-5.17.269.1-sources.jar: zio/aws/ec2/model/PrefixListId.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class PrefixListId(
    description: Optional[String] = Optional.Absent,
    prefixListId: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.PrefixListId = {
    import PrefixListId.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.PrefixListId
      .builder()
      .optionallyWith(description.map(value => value: java.lang.String))(
        _.description
      )
      .optionallyWith(prefixListId.map(value => value: java.lang.String))(
        _.prefixListId
      )
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.PrefixListId.ReadOnly =
    zio.aws.ec2.model.PrefixListId.wrap(buildAwsValue())
}
object PrefixListId {
  private lazy val zioAwsBuilderHelper
      : BuilderHelper[software.amazon.awssdk.services.ec2.model.PrefixListId] =
    BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.PrefixListId =
      zio.aws.ec2.model.PrefixListId(
        description.map(value => value),
        prefixListId.map(value => value)
      )
    def description: Optional[String]
    def prefixListId: Optional[String]
    def getDescription: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("description", description)
    def getPrefixListId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("prefixListId", prefixListId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.PrefixListId
  ) extends zio.aws.ec2.model.PrefixListId.ReadOnly {
    override val description: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.description())
      .map(value => value: String)
    override val prefixListId: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.prefixListId())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.PrefixListId
  ): zio.aws.ec2.model.PrefixListId.ReadOnly = new Wrapper(impl)
}
